@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional, Union, List, Any
+from typing import Optional, Union
 from dataclasses import dataclass
 
 
